@@ -9,6 +9,7 @@ OC.L10N.register(
     "New" : "Nevez",
     "New folder" : "Heuliad nevez",
     "Search" : "Klask",
+    "Empty trash bin" : "Pod-lastez goullo",
     "Sort by created date" : "Renkañ dre deizat krouidigezh",
     "Submit" : "Kinnig",
     "Cancel" : "Arrest",
@@ -17,11 +18,11 @@ OC.L10N.register(
     "Files" : "Restroù",
     "Broken links" : "Liammoù toret",
     "Delete" : "Dilemel",
-    "Settings" : "Arventennoù",
     "Need help?" : "Sikour o po ?",
     "Title" : "Titl",
     "Link" : "Liamm",
     "Tags" : "Klavioù",
+    "Notes" : "Notennoù",
     "Download file" : "Pelkargañ restr",
     "Owner" : "Perc'henner",
     "Sharing" : "Rannan",
