@@ -26,7 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s ha dejado de compartir la carpeta «%2$s» contigo",
     "Someone unshared folder \"%s\" with you" : "Alguien ha dejado de compartir la carpeta «%s» contigo",
     "No file provided for import" : "No se seleccionó un archivo para importar",
-    "Unsupported file type for import" : "Tipo de archivo no soportado",
+    "Failed to upload file" : "Error al subir el archivo",
     "Bookmarks shared by %s" : "Marcadores compartidos por %s",
     "Frequent bookmarks" : "Marcadores frecuentes",
     "Recent bookmarks" : "Marcadores recientes",
@@ -65,8 +65,6 @@ OC.L10N.register(
     "Cancel selection" : "Cancelar selección",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Seleccionadas {folders} carpetas y {bookmarks} marcadores",
     "Do you really want to delete these items?" : "¿Estás seguro de que quieres eliminar estos elementos?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Seleccionado %n marcador","Seleccionados %n marcadores","Seleccionados %n marcadores"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Seleccionada%n carpeta","Seleccionadas %n carpetas","Seleccionadas %n carpetas"],
     "Go back" : "Ir atrás",
     "Share folder" : "Compartir carpeta",
     "Select one or more tags" : "Selecciona una o más etiquetas",
@@ -78,6 +76,7 @@ OC.L10N.register(
     "Copy RSS Feed of current view" : "Copiar la Fuente RSS de la vista actual",
     "The RSS feed requires authentication with your Nextcloud credentials" : "La Fuente RSS requiere autenticar con tus credenciales de Nextcloud",
     "Search" : "Buscar",
+    "Empty trash bin" : "Vacíar la papelera",
     "Sort by created date" : "Ordenar por fecha de creación",
     "Sort by last modified" : "Ordenar por último modificado",
     "Sort by title" : "Ordenar por título",
@@ -85,13 +84,10 @@ OC.L10N.register(
     "Sort by manual order" : "Ordenar manualmente",
     "Sort by URL" : "Ordenar por URL",
     "RSS feed copied" : "Fuente RSS copiada",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Añadiendo %n marcador a una nueva carpeta","Añadiendo %n marcadores a una nueva carpeta","Añadiendo %n marcadores a una nueva carpeta"],
     "Enter a link" : "Introduce un enlace",
     "Enter a title" : "Introduce un título",
     "No bookmarks found" : "No se han encontrado marcadores",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} carpetas {bookmarks} marcadores",
-    "_%n bookmark_::_%n bookmarks_" : ["%n marcador","%n marcadores","%n marcadores"],
-    "_%n folder_::_%n folders_" : ["%n carpeta","%n carpetas","%n carpetas"],
     "Welcome to Bookmarks" : "Bienvenido a Marcadores",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Esta app le permite gestionar enlaces a sus lugares favoritos de la web. ¡Organice sus marcadores en carpetas, etiquete los mismos y compártelos con otros!. La app verificará periódicamente su disponibilidad y mostrará los que ya no son accesibles. Si añade un enlace a un archivo en la web, el mismo será automáticamente descargado a sus Archivos de Nextcloud. También puede importar marcadores de otros servicios o sincronizar directamente sus marcadores de todos sus navegadores con esta app.",
     "Add a bookmark" : "Añadir un marcador",
@@ -110,9 +106,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Importando marcadores",
     "Moving selection" : "Moviendo la selección",
     "Adding selection to folders" : "Añadiendo selección a las carpetas",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Moviendo %ncarpeta y algunos marcadores","Moviendo %n carpetas y algunos marcadores","Moviendo %n carpetas y algunos marcadores"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Moviendo %ncarpeta","Moviendo %n carpetas","Moviendo %n carpetas"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Moviendo %n marcador","Moviendo %n marcadores","Moviendo %n marcadores"],
     "All bookmarks" : "Todos los marcadores",
     "Recent" : "Reciente",
     "Shared with you" : "Compartido con Ud.",
@@ -124,7 +117,6 @@ OC.L10N.register(
     "Delete" : "Eliminar",
     "Untagged" : "Sin etiquetar",
     "{used} bookmarks of {available} available" : "{used} marcadores de {available} disponibles",
-    "Settings" : "Ajustes",
     "No bookmarked files" : "Sin archivos marcadores",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Marcar archivos como fotos o PDF harán que se guarden automáticamente en tus archivos de Nextcloud, para que puedas encontrarlos incluso cuando el enlace queda fuera de línea.",
     "Nothing found" : "No se encontró nada",
