@@ -26,7 +26,6 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s lopetti kansion \"%2$s\" jakamisen kanssasi",
     "Someone unshared folder \"%s\" with you" : "Joku lopetti kansion \"%s\" jaon kanssasi",
     "No file provided for import" : "Tuotavaa tiedostoa ei ole valittu",
-    "Unsupported file type for import" : "Tiedoston tyyppi ei ole tuotavaa muotoa",
     "Bookmarks shared by %s" : "Henkilön %s jakamat kirjanmerkit",
     "Frequent bookmarks" : "Usein käytetyt kirjanmerkit",
     "Recent bookmarks" : "Viimeisimmät kirjanmerkit",
@@ -70,8 +69,6 @@ OC.L10N.register(
     "Cancel selection" : "Peruuta valinta",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Valittu {folders} kansiota ja {bookmarks} kirjanmerkkiä",
     "Do you really want to delete these items?" : "Haluatko varmasti poistaa kohteet?",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Valittu %n kirjanmerkki","Valittu %n kirjanmerkkiä"],
-    "_Selected %n folder_::_Selected %n folders_" : ["Valittu %n kansio","Valittu %n kansiota"],
     "Trash Bin" : "Roskakori",
     "Go back" : "Mene takaisin",
     "Share folder" : "Jaa kansio",
@@ -92,13 +89,10 @@ OC.L10N.register(
     "Sort by manual order" : "Lajittele manuaalisen järjestyksen mukaan",
     "Sort by URL" : "Järjestä URL-osoitteen mukaan",
     "RSS feed copied" : "RSS-syöte kopioitu",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["Lisätään %n kirjanmerkki uuteen kansioon","Lisätään %n kirjanmerkkiä uuteen kansioon"],
     "Enter a link" : "Anna linkki",
     "Enter a title" : "Syötä nimi",
     "No bookmarks found" : "Kirjanmerkkejä ei löytynyt",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} kansiota ja {bookmarks} kirjanmerkkiä",
-    "_%n bookmark_::_%n bookmarks_" : ["%n kirjanmerkki","%n kirjanmerkkiä"],
-    "_%n folder_::_%n folders_" : ["%n kansio","%n kansiota"],
     "Welcome to Bookmarks" : "Tervetuloa kirjanmerkkeihin",
     "Add a bookmark" : "Lisää kirjanmerkki",
     "Import bookmarks" : "Tuo kirjanmerkit",
@@ -120,9 +114,6 @@ OC.L10N.register(
     "Importing bookmarks" : "Tuodaan kirjanmerkkejä",
     "Moving selection" : "Siirretään valittua kohdetta",
     "Adding selection to folders" : "Lisätään valinta kansioihin",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Siirretään %n kansio ja joitain kirjanmerkkejä","Siirretään %n kansiota ja joitain kirjanmerkkejä"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Siirretään %n kansio","Siirretään %n kansiota"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Siirretään %n kirjanmerkki","Siirretään %n kirjanmerkkiä"],
     "All bookmarks" : "Kaikki kirjanmerkit",
     "Recent" : "Viimeisimmät",
     "Shared with you" : "Jaettu kanssasi",
@@ -134,7 +125,6 @@ OC.L10N.register(
     "Delete" : "Poista",
     "Untagged" : "Ilman tunnistetta",
     "{used} bookmarks of {available} available" : "{used}/{available} kirjanmerkkiä käytettävissä",
-    "Settings" : "Asetukset",
     "No bookmarked files" : "Ei kirjanmerkiksi lisättyjä tiedostoja",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Kirjanmerkit tiedostoihin, kuten kuviin tai PDF-tiedostoihin tallennetaan automaattisesti Nextcloudin tiedostoihin, joten löydät ne vaikka linkki ei olisi käytössä.",
     "Nothing found" : "Mitään ei löytynyt",
