@@ -16,7 +16,6 @@ OC.L10N.register(
     "Someone deleted folder \"%s\"" : "Kažkas ištrynė aplanką \"%s\"",
     "You shared folder \"%1$s\" with %2$s" : "Jūs pradėjote bendrinti aplanką „%1$s“ su %2$s",
     "No file provided for import" : "Importavimui nepateiktas joks failas",
-    "Unsupported file type for import" : "Importavimui pateiktas nepalaikomas failo tipas",
     "Select bookmark" : "Pasirinkti adresyno įrašą",
     "Details" : "Išsamiau",
     "Rename" : "Pervadinti",
@@ -26,7 +25,6 @@ OC.L10N.register(
     "Move selection" : "Perkelti žymėjimą",
     "Delete selection" : "Ištrinti žymėjimą",
     "Select all" : "Pažymėti viską",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Pažymėtas %n adresyno įrašas","Pažymėti %n adresyno įrašai","Pažymėta %n adresyno įrašų","Pažymėtas %n adresyno įrašas"],
     "Go back" : "Grįžti",
     "Share folder" : "Bendrinti aplanką",
     "Select one or more tags" : "Pasirinkite vieną ar daugiau žymių",
@@ -46,16 +44,12 @@ OC.L10N.register(
     "Choose folder" : "Pasirinkti aplanką",
     "Submit" : "Pateikti",
     "Cancel" : "Atsisakyti",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["Perkeliamas %n aplankas ir keli adresyno įrašai","Perkeliami %n aplankai ir keli adresyno įrašai","Perkeliama %n aplankų ir keli adresyno įrašai","Perkeliamas %n aplankas ir keli adresyno įrašai"],
-    "_Moving %n folder_::_Moving %n folders_" : ["Perkeliamas %n aplankas","Perkeliami %n aplankai","Perkeliama %n aplankų","Perkeliamas %n aplankas"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["Perkeliamas %n adresyno įrašas","Perkeliami %n adresyno įrašai","Perkeliama %n adresyno įrašų","Perkeliamas %n adresyno įrašas"],
     "Recent" : "Paskiausi",
     "Shared with you" : "Bendrinama su jumis",
     "Files" : "Failai",
     "New tag" : "Nauja žymė",
     "Delete" : "Ištrinti",
     "Untagged" : "Be žymių",
-    "Settings" : "Nustatymai",
     "No bookmarks here" : "Čia adresyno įrašų nėra",
     "Client apps" : "Kliento programėlės",
     "Add to {instanceName}" : "Pridėti į {instanceName}",
