@@ -26,7 +26,6 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s прибрав(-ла) доступ до каталогу \"%2$s\" для вас",
     "Someone unshared folder \"%s\" with you" : "Хтось прибрав доступ до каталогу \"%s\" для вас",
     "No file provided for import" : "Відсутній файл для імпорту",
-    "Unsupported file type for import" : "Цей тип файлу не підтримується",
     "Bookmarks shared by %s" : "Закладки, якими поділив(-ла)ся %s",
     "Frequent bookmarks" : "Часті закладки",
     "Recent bookmarks" : "Останні закладки",
@@ -57,17 +56,25 @@ OC.L10N.register(
     "This content is being downloaded for offline use. Please check back later." : "Вміст звантажується для використання в автономному режимі. Будь ласка, перевірте пізніше.",
     "Bookmarked {time} ago" : "Закладку створено {time} назад",
     "Bookmarked on {date}" : "Закладку створено {date}",
+    "These are your deleted items. Items will be deleted permanently after two months." : "Тут розташовано вилучені об'єкти, які буде вилучено остаточно через 2 місяці.",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Закладки на файли в мережі, такі як світлини або файли PDF, буде автоматично збережено до ваших файлів у хмарі Nextcloud. Таким чином ви зможете завжди їх знаходити, навіть якщо посилання будуть недоступні.",
+    "Searching in the current folder only." : "Шукати тільки в поточному каталозі.",
+    "Repeat search in all folders" : "Повторити пошук у всіх каталогах",
     "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "Закладки на посилання в мережі періодично перевіряються на доступність. Закладки, до яких відсутній доступ, буде наведено тут.",
     "You can share bookmark folders with others. All folders shared with you are listed here." : "Ви можете поділитися каталогами закладок з іншими користувачами. Усі каталоги, якими поділилися з вами, буде наведено тут.",
     "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "Одна й та саме закладка може міститися одночасно в різних каталогах. Внесення змін до такої закладки оновить всі її копії. Повторювані закладки наведено тут для зручности.",
+    "Open all selected" : "Відкрити всі вибрані",
+    "Move selection" : "Перемістити вибране",
+    "Edit tags of selection" : "Редагувати мітки вибраного",
     "Delete selection" : "Прибрати виділення",
     "Select all" : "Вибрати все",
+    "Cancel selection" : "Скасувати вибір",
     "Selected {folders} folders and {bookmarks} bookmarks" : "Вибрано {folders} каталогів та {bookmarks} закладок",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["Вибрано %n закладку","Вибрано %n закладки","Вибрано %n закладок","Вибрано %n закладок"],
+    "Do you really want to delete these items?" : "Дійсно вилучити ці об'єкти?",
     "Trash Bin" : "Кошик",
     "Go back" : "Повернутися назад",
     "Share folder" : "Спільний доступ до каталогу",
+    "Open folder details" : "Показати деталі каталогу",
     "Select one or more tags" : "Виберіть одну або кілька міток",
     "New" : "Створити",
     "New bookmark" : "Нова закладка",
@@ -78,11 +85,17 @@ OC.L10N.register(
     "The RSS feed requires authentication with your Nextcloud credentials" : "Стрічка RSS вимагає авторизації з вашим обліковим записом у хмарі Nextcloud",
     "Search" : "Пошук",
     "Empty trash bin" : "Очистити кошик",
+    "Sort by created date" : "Впорядкувати за датою створення",
     "Sort by last modified" : "Впорядкувати за останніми змінами",
     "Sort by title" : "Впорядкувати за назвою",
+    "Sort by click count" : "Впорядкувати за кількістю переходів",
+    "Sort by manual order" : "Впорядкувати вручну",
+    "Sort by URL" : "Впорядкувати за посиланнями",
+    "RSS feed copied" : "Стрічку RSS скопійовано",
     "Enter a link" : "Зазначте посилання",
     "Enter a title" : "Зазначте заголовок",
     "No bookmarks found" : "Закладки не знайдено",
+    "{folders} folders and {bookmarks} bookmarks" : "{folders} каталогів та {bookmarks} закладок",
     "Welcome to Bookmarks" : "Вітаємо у застосунку \"Закладки\"",
     "Add a bookmark" : "Додати закладку",
     "Import bookmarks" : "Імпорт закладок",
@@ -95,10 +108,15 @@ OC.L10N.register(
     "Put folder into trashbin" : "Вилучити каталог",
     "Restore folder" : "Відновити каталог",
     "Delete folder permanently" : "Вилучити каталог назавжди",
+    "Do you really want to permanently delete this folder?" : "Дійсно вилучити цей каталог без можливості відновлення?",
     "Choose folder" : "Виберіть каталог",
     "Submit" : "Гаразд",
     "Cancel" : "Скасувати",
+    "Deleting bookmarks" : "Вилучення закладок",
+    "Deleting selection" : "Вилучення вибраного",
     "Importing bookmarks" : "Відбувається імпорт закладок",
+    "Moving selection" : "Переміщення вибраного",
+    "Adding selection to folders" : "Додавання вибору до каталогів",
     "All bookmarks" : "Усі закладки",
     "Recent" : "Останні",
     "Shared with you" : "Спільні",
@@ -109,10 +127,12 @@ OC.L10N.register(
     "Search tags" : "Шукати мітки",
     "Delete" : "Вилучити",
     "Untagged" : "Без мітки",
-    "Settings" : "Налаштування",
+    "{used} bookmarks of {available} available" : "{used} із {available} закладок доступно",
+    "Bookmarks Settings" : "Налаштування закладок",
     "No bookmarked files" : "Відсутні закладки з файлами",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "Закладки на файли, такі як світлини або файли PDF, буде автоматично збережено до ваших файлів у хмарі Nextcloud. Таким чином ви зможете завжди їх знаходити, навіть якщо посилання будуть недоступні.",
     "Nothing found" : "Нічого не знайдено",
+    "Your search yielded no results in the current folder." : "Нічого не знайдено в поточному каталозі.",
     "No broken links" : "Відсутні загублені посилання",
     "No shared folders" : "З вами ще ніхто не поділився каталогами",
     "No duplicated bookmarks" : "Відсутні повторювані закладки",
@@ -124,13 +144,17 @@ OC.L10N.register(
     "Import/Export" : "Імпорт/експорт",
     "Export bookmarks" : "Експорт закладок",
     "Auto-archiving" : "Архівні копії",
+    "The bookmarks app can automatically archive the web content of links you have bookmarked" : "Застосунок \"Закладки\" може автоматично архівувати вміст посилань, які ви поставили у закладки",
     "Enable archiving" : "Увімкнути збереження архівів",
+    "Enter the path of a folder in your Files where bookmarked files should be stored." : "Зазначте шлях до каталогу у Файлах для збереження закладок",
+    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "Адміністратор вимкнув доступ до цього застосунку, тому автоматичне архівування наразі недоступне.",
     "Auto-Backup" : "Резервні копії",
+    "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "Застосунок \"Закладки\" може автоматично створювати щоденні резервні копії ваших закладок, що унеможливить втрату даних під час синхронізації закладок між пристроями.",
     "Enable backups" : "Увімкнути збереження резервних копій",
     "Client apps" : "Застосунки",
     "Install web app" : "Вебзастосунки",
     "Install on home screen" : "Встановити на домівці",
-    "Add to {instanceName}" : "Додати до{instanceName}",
+    "Add to {instanceName}" : "Додати до {instanceName}",
     "Need help?" : "Потрібна допомога?",
     "Support this project" : "Підтримати",
     "Archive path" : "Шлях до архівних копій",
