@@ -26,7 +26,7 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s取消了开放给您的%2$s文件夹共享",
     "Someone unshared folder \"%s\" with you" : "有人取消了开放给您的%s文件夹共享",
     "No file provided for import" : "未提供导入文件",
-    "Unsupported file type for import" : "不支持导入的文件类型",
+    "Failed to upload file" : "上传文件失败",
     "Bookmarks shared by %s" : "由 %s 共享的书签",
     "Frequent bookmarks" : "常用书签",
     "Recent bookmarks" : "近期书签",
@@ -63,8 +63,6 @@ OC.L10N.register(
     "Cancel selection" : "取消选择",
     "Selected {folders} folders and {bookmarks} bookmarks" : "已选择文件夹 {folders} 和书签 {bookmarks} ",
     "Do you really want to delete these items?" : "你真想删除这些项目吗？",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["选择了%n个书签"],
-    "_Selected %n folder_::_Selected %n folders_" : ["选定%n个文件夹 "],
     "Go back" : "返回",
     "Share folder" : "分享文件夹",
     "Select one or more tags" : "选择一个或多个标签",
@@ -84,13 +82,10 @@ OC.L10N.register(
     "Sort by manual order" : "按手动顺序排序",
     "Sort by URL" : "按 URL 排序",
     "RSS feed copied" : "RSS提要已复制",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["将%n个书签添加至新文件夹"],
     "Enter a link" : "输入一个链接",
     "Enter a title" : "输入标题",
     "No bookmarks found" : "未找到书签",
     "{folders} folders and {bookmarks} bookmarks" : "{folders}个文件夹和{bookmarks}枚书签",
-    "_%n bookmark_::_%n bookmarks_" : ["%n枚书签"],
-    "_%n folder_::_%n folders_" : ["%n个文件夹"],
     "Welcome to Bookmarks" : "欢迎使用书签",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此应用程序让你可以管理网络上您喜爱之处的链接。将您的书签整理到文件夹中，用标签标记，以及与其他人分享它们！应用程序会定期检查您所有链接的可用性，并显示无法使用的链接。如果您添加一个指向在线文件的链接，文件将会自动下载到您的文件中。您还可以导入从其他服务导出的书签，或是直接从您的所有浏览器中的书签同步到此应用程序。",
     "Add a bookmark" : "添加书签",
@@ -109,9 +104,6 @@ OC.L10N.register(
     "Importing bookmarks" : "正在导入书签",
     "Moving selection" : "正在移动所选对象",
     "Adding selection to folders" : "添加选中项到文件夹",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移动%n个文件夹和一些书签"],
-    "_Moving %n folder_::_Moving %n folders_" : ["正在移动%n个文件夹"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移动%n个书签"],
     "All bookmarks" : "全部书签",
     "Recent" : "最近",
     "Shared with you" : "已共享给您",
@@ -123,7 +115,6 @@ OC.L10N.register(
     "Delete" : "删除",
     "Untagged" : "未标记的",
     "{used} bookmarks of {available} available" : " {available}书签可用，已用{used}",
-    "Settings" : "设置",
     "No bookmarked files" : "无已添加书签的文件",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等文件的书签会被自动保存到你的Nextcloud文件中，因此即使链接离线，你仍然可以找到它们。",
     "No broken links" : "没有失效的链接",
