@@ -26,7 +26,8 @@ OC.L10N.register(
     "%1$s unshared folder \"%2$s\" with you" : "%1$s 已取消與您分享的資料夾「%2$s」",
     "Someone unshared folder \"%s\" with you" : "某人已取消與你分享的資料夾「%s」",
     "No file provided for import" : "未提供要匯入的檔案",
-    "Unsupported file type for import" : "匯入不支援的檔案格式",
+    "Failed to upload file" : "上傳檔案失敗",
+    "Unsupported file type for import: " : "匯入不支援的檔案格式：",
     "Bookmarks shared by %s" : "由 %s 分享的書籤",
     "Frequent bookmarks" : "常用書籤",
     "Recent bookmarks" : "最近的書籤",
@@ -73,11 +74,10 @@ OC.L10N.register(
     "Cancel selection" : "取消選取",
     "Selected {folders} folders and {bookmarks} bookmarks" : "選定的 {folders} 資料夾與 {bookmarks} 書籤",
     "Do you really want to delete these items?" : "您想要刪除這些項目嗎？",
-    "_Selected %n bookmark_::_Selected %n bookmarks_" : ["已選取 %n 書籤"],
-    "_Selected %n folder_::_Selected %n folders_" : ["已選取%n個資料夾"],
     "Trash Bin" : "垃圾桶",
     "Go back" : "返回",
     "Share folder" : "分享資料夾",
+    "Open folder details" : "開啟資料夾詳細資訊",
     "Select one or more tags" : "選取一個或更多標籤",
     "New" : "新增",
     "New bookmark" : "新增書籤",
@@ -95,13 +95,10 @@ OC.L10N.register(
     "Sort by manual order" : "手動排序",
     "Sort by URL" : "按 URL 排序",
     "RSS feed copied" : "RSS feed 已複製",
-    "_Adding %n bookmark to new folder_::_Adding %n bookmarks to new folder_" : ["正在新增 %n 書籤至新資料夾"],
     "Enter a link" : "輸入連結",
     "Enter a title" : "輸入標題",
     "No bookmarks found" : "找不到書籤",
     "{folders} folders and {bookmarks} bookmarks" : "{folders} 資料夾與 {bookmarks} 書籤",
-    "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
-    "_%n folder_::_%n folders_" : ["%n 資料夾"],
     "Welcome to Bookmarks" : "歡迎使用書籤",
     "This app allows you to manage links to your favorite places on the web. Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "此應用程式讓您可以管理網路上您最愛之處的連結。將您的書籤分類至資料夾中，用標籤標記它們並與其他人分享！應用程式會定期檢查您所有連結的可用性，並顯示無法使用的連結。若您在網路上新增指向檔案的連結，該檔案將會自動下載到您的 Nextcloud Files 中。您也可以匯入從其他服務匯出的書籤，或是直接將所有瀏覽器中的書籤與此應用程式同步。",
     "Add a bookmark" : "新增書籤",
@@ -124,9 +121,7 @@ OC.L10N.register(
     "Importing bookmarks" : "正在匯入書籤",
     "Moving selection" : "正在移動選擇",
     "Adding selection to folders" : "正在新增選定的項目至資料夾",
-    "_Moving %n folder and some bookmarks_::_Moving %n folders and some bookmarks_" : ["正在移動%n個資料夾和一些書籤"],
-    "_Moving %n folder_::_Moving %n folders_" : ["正在移動%n個資料夾"],
-    "_Moving %n bookmark_::_Moving %n bookmarks_" : ["正在移動%n個書籤"],
+    "Emptying trashbin" : "清空回收桶",
     "All bookmarks" : "所有書籤",
     "Recent" : "近期",
     "Shared with you" : "與您分享",
@@ -138,7 +133,7 @@ OC.L10N.register(
     "Delete" : "刪除",
     "Untagged" : "無標籤",
     "{used} bookmarks of {available} available" : "{used} 書籤，可用 {available}",
-    "Settings" : "設定",
+    "Bookmarks Settings" : "書籤設定",
     "No bookmarked files" : "沒有已加入書籤的檔案",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或 PDF 等檔案的書籤將會自動儲存到您的 Nextcloud 檔案中，因此即便連結離線，您也仍然可以找到它們。",
     "Nothing found" : "找不到東西",
@@ -157,6 +152,7 @@ OC.L10N.register(
     "The bookmarks app can automatically archive the web content of links you have bookmarked" : "書籤應用程式可以自動封存您加入書籤的網路內容",
     "Enable archiving" : "啟用封存",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "輸入要儲存書籤檔案的資料夾路徑。",
+    "Currently your administrator has disabled network access for this app, however, which is why Auto-archiving is disabled at the moment." : "目前，您的管理員已停用此應用程式的網路存取，這就是此刻停用自動封存的原因。",
     "Auto-Backup" : "自動備份",
     "The bookmarks app can automatically backup your bookmarks on a daily basis to prevent data loss when syncing bookmarks across devices." : "書籤應用程式可以每天自動備份您的書籤，以防止跨裝置同步書籤時遺失資料。",
     "Enable backups" : "啟用備份",
