@@ -20,7 +20,8 @@ class ExceptionMiddleware extends Middleware {
 	public function afterException($controller, $methodName, \Exception $exception): DataResponse {
 		if ($controller instanceof BookmarkController || $controller instanceof InternalBookmarkController || $controller instanceof FoldersController || $controller instanceof InternalFoldersController) {
 			if ($exception instanceof UnauthenticatedError) {
-				$res = new DataResponse(['status' => 'error', 'data' => 'Please authenticate first'], Http::STATUS_UNAUTHORIZED);
+				$res = new DataResponse(['status' => 'error', 'data' => ['Please authenticate first']], Http::STATUS_UNAUTHORIZED);
+				$res->throttle();
 				$res->addHeader('WWW-Authenticate', 'Basic realm="Nextcloud Bookmarks", charset="UTF-8"');
 				return $res;
 			}
