@@ -137,7 +137,7 @@ class BookmarkService {
 		$bookmark = null;
 		$ownFolders = array_filter($folders, function ($folderId) use ($userId) {
 			/**
-			 * @var $folder Folder
+			 * @var Folder $folder
 			 */
 			$folder = $this->folderMapper->find($folderId);
 			return $folder->getUserId() === $userId;
@@ -145,7 +145,7 @@ class BookmarkService {
 		$foreignFolders = array_diff($folders, $ownFolders);
 		foreach ($foreignFolders as $folderId) {
 			/**
-			 * @var $folder Folder
+			 * @var Folder $folder
 			 */
 			$folder = $this->folderMapper->find($folderId);
 			$bookmark = $this->_addBookmark($folder->getUserId(), $url, $title, $description, $tags, [$folder->getId()]);
@@ -177,6 +177,7 @@ class BookmarkService {
 	 * @throws UnsupportedOperation
 	 * @throws UrlParseError
 	 * @throws UserLimitExceededError
+	 * @throws DoesNotExistException
 	 */
 	private function _addBookmark($userId, $url, ?string $title = null, ?string $description = null, ?array $tags = null, array $folders = []): Bookmark {
 		$bookmark = null;
@@ -247,6 +248,9 @@ class BookmarkService {
 		}
 
 		$this->treeMapper->addToFolders(TreeMapper::TYPE_BOOKMARK, $bookmark->getId(), $folders);
+		foreach ($folders as $folderId) {
+			$this->treeMapper->softUndeleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId(), $folderId);
+		}
 		$this->eventDispatcher->dispatch(CreateEvent::class,
 			new CreateEvent(TreeMapper::TYPE_BOOKMARK, $bookmark->getId())
 		);
@@ -275,7 +279,7 @@ class BookmarkService {
 	 */
 	public function update(string $userId, int $id, ?string $url = null, ?string $title = null, ?string $description = null, ?array $tags = null, ?array $folders = null): ?Bookmark {
 		/**
-		 * @var $bookmark Bookmark
+		 * @var Bookmark $bookmark
 		 */
 		$bookmark = $this->bookmarkMapper->find($id);
 
@@ -333,7 +337,7 @@ class BookmarkService {
 			}
 
 			/**
-			 * @var $currentOwnFolders Folder[]
+			 * @var Folder[] $currentOwnFolders
 			 */
 			$currentOwnFolders = $this->treeMapper->findParentsOf(TreeMapper::TYPE_BOOKMARK, $bookmark->getId());
 			// Updating user may not be the owner of the bookmark
@@ -354,6 +358,10 @@ class BookmarkService {
 			if (count($ownFolders) === 0) {
 				$this->bookmarkMapper->delete($bookmark);
 				return null;
+			} else {
+				foreach ($ownFolders as $folderId) {
+					$this->treeMapper->softUndeleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId(), $folderId);
+				}
 			}
 		}
 
@@ -431,7 +439,7 @@ class BookmarkService {
 	 */
 	public function delete(int $id): void {
 		$bookmark = $this->bookmarkMapper->find($id);
-		$parents = $this->treeMapper->findParentsOf(TreeMapper::TYPE_BOOKMARK, $id);
+		$parents = $this->treeMapper->findParentsOf(TreeMapper::TYPE_BOOKMARK, $id, true);
 		foreach ($parents as $parent) {
 			$this->treeMapper->deleteEntry(TreeMapper::TYPE_BOOKMARK, $bookmark->getId(), $parent->getId());
 		}
