@@ -1,6 +1,6 @@
 <?php
 /*
- * Copyright (c) 2020. The Nextcloud Bookmarks contributors.
+ * Copyright (c) 2020-2024. The Nextcloud Bookmarks contributors.
  *
  * This file is licensed under the Affero General Public License version 3 or later. See the COPYING file.
  */
@@ -57,8 +57,8 @@ class ScreenshotMachineBookmarkPreviewer implements IBookmarkPreviewer {
 	 *
 	 * @return Image|null
 	 */
-	public function getImage($bookmark): ?IImage {
-		if (!isset($bookmark)) {
+	public function getImage($bookmark, $cacheOnly = false): ?IImage {
+		if (!isset($bookmark) || $cacheOnly) {
 			return null;
 		}
 		if ($this->apiKey === '') {
@@ -78,13 +78,13 @@ class ScreenshotMachineBookmarkPreviewer implements IBookmarkPreviewer {
 		try {
 			// get it
 			$response = $this->client->get(
-				"https://api.screenshotmachine.com/?key=". $this->apiKey . "&dimension=" . $this->width . "x" . $this->height . "&device=desktop&delay=2000&format=jpg&url=" . $url,
+				'https://api.screenshotmachine.com/?key=' . $this->apiKey . '&dimension=' . $this->width . 'x' . $this->height . '&device=desktop&delay=2000&format=jpg&url=' . $url,
 				[
 					'timeout' => self::HTTP_TIMEOUT,
 				]
 			);
 			// Some HTPP Error occured :/
-			if (200 !== $response->getStatusCode()) {
+			if ($response->getStatusCode() !== 200) {
 				return null;
 			}
 			$body = $response->getBody();
